==> kadu_0.10.1.orig.tar.bz2: kadu-0.10.1/plugins/encryption_ng/translations/encryption_ng_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encrypt by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encrypt after receive encrypted message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Public key has been sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error during sending public key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption error has occured</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EncryptionActions</name>
    <message>
        <source>Generate Encryption Keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encrypt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send My Public Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot generate keys. Check if encryption_simlite module is loaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keys exist. Do you want to overwrite them?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keys have been generated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error generating keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No public key available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EncryptionNgNotification</name>
    <message>
        <source>Encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Public key has been send to: %1 (%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error sending public key to: %1 (%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error occured during encryption</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EncryptionNgPlugin</name>
    <message>
        <source>Encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The QCA OSSL plugin for libqca2 is not present!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EncryptionProviderManager</name>
    <message>
        <source>Buddy %1 is sending you his public key.
Do you want to save it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu_0.11.0~rc2.orig.tar.bz2: kadu-0.11.0-rc2/plugins/encryption_ng/translations/encryption_ng_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encrypt by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encrypt after receive encrypted message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Public key has been sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error during sending public key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption error has occured</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EnableEncryptionActionDescription</name>
    <message>
        <source>Encrypt</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EncryptionNgNotification</name>
    <message>
        <source>Encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Public key has been send to: %1 (%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error sending public key to: %1 (%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error occured during encryption</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EncryptionNgPlugin</name>
    <message>
        <source>Encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The QCA OSSL plugin for libqca2 is not present!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EncryptionProviderManager</name>
    <message>
        <source>Buddy %1 is sending you his public key.
Do you want to save it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GenerateKeysActionDescription</name>
    <message>
        <source>Generate Encryption Keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot generate keys. Check if encryption_simlite module is loaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keys exist. Do you want to overwrite them?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keys have been generated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error generating keys</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SendPublicKeyActionDescription</name>
    <message>
        <source>Send My Public Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No public key available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
